@@ -2,10 +2,14 @@ import os
 import shutil
 import subprocess  # nosec
 import sys
+from tempfile import TemporaryDirectory
 from typing import List
 
 import typer
+from typer import Option
 
+import belay
+from belay.cli import cache
 from belay.cli.clean import clean
 from belay.cli.exec import exec
 from belay.cli.identify import identify
@@ -17,7 +21,9 @@ from belay.cli.sync import sync
 from belay.cli.update import update
 from belay.project import load_groups
 
-app = typer.Typer()
+app = typer.Typer(no_args_is_help=True, pretty_exceptions_enable=False)
+app.add_typer(cache.app, name="cache")
+
 app.command()(clean)
 app.command()(exec)
 app.command()(identify)
@@ -34,12 +40,16 @@ def run_exec(command: List[str]):
     groups = load_groups()
     virtual_env = os.environ.copy()
     # Add all dependency groups to the micropython path.
-    virtual_env["MICROPYPATH"] = os.pathsep.join(str(g.folder) for g in groups)
-    return subprocess.run(  # nosec
-        command,
-        env=virtual_env,
-        check=True,
-    ).returncode
+    with TemporaryDirectory() as tmp_dir:
+        virtual_env["MICROPYPATH"] = tmp_dir
+        for group in groups:
+            group.copy_to(tmp_dir)
+
+        return subprocess.run(  # nosec
+            command,
+            env=virtual_env,
+            check=True,
+        ).returncode
 
 
 def _get(indexable, index, default=None):
@@ -64,3 +74,24 @@ def run_app(*args, **kwargs):
 
     # Common-case; use Typer functionality.
     app(*args, **kwargs)
+
+
+def version_callback(value: bool):
+    if not value:
+        return
+    print(belay.__version__)
+    raise typer.Exit()
+
+
+@app.callback()
+def common(
+    ctx: typer.Context,
+    version: bool = Option(
+        None,
+        "--version",
+        "-v",
+        callback=version_callback,
+        help="Display Belay's version.",
+    ),
+):
+    pass
